@@ -27,6 +27,7 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
@@ -261,7 +262,7 @@ static gint updateOutput(gpointer data)
 	GList *sources, *dests;
 	GnomeVFSURI *source_uri, *dest_uri;
 	char *source_text_uri, *dest_text_uri;
-	GnomeVFSAsyncHandle *vfshandle;
+	char *escaped;
 
 	if (stockdata->vfshandle != NULL) {
 		gnome_vfs_async_cancel (stockdata->vfshandle);
@@ -287,10 +288,13 @@ static gint updateOutput(gpointer data)
          * v: volume
          * The digit following some data specifiers change data formating (html/raw)
          */
+
+	escaped = gnome_vfs_escape_string(stockdata->props.tik_syms);
 	source_text_uri = g_strconcat("http://finance.yahoo.com/d/quotes.csv?s=",
-				      stockdata->props.tik_syms,
+				      escaped,
 				      "&f=sl1c1&e=.csv",
 				      NULL);
+	g_free (escaped);
 
 	source_uri = gnome_vfs_uri_new(source_text_uri);
 	sources = g_list_append(NULL, source_uri);
@@ -423,63 +427,55 @@ static gint updateOutput(gpointer data)
 
 
 	/*-----------------------------------------------------------------*/
-	static char *parseQuote(char line[MAX_SYMBOL_LEN]) {
-		
-                char *symbol;
-                char *price;
-                char *change;
-                double price_val; 
-                double change_val; 
-                double percent;
-                static char result[512]="";
+	static char *parseQuote(char line[MAX_SYMBOL_LEN])
+	{
+		char *result = NULL;
+		char **tokens;
+		char *symbol;
+		double price_val; 
+		double change_val; 
+		double percent;
 
-                /* Yahoo file comme in C format */
-                setlocale(LC_NUMERIC, "C");
-                
-                symbol = strtok(line, ",");
-                symbol++;
-                symbol[strlen(symbol) -1] = 0;
-                g_message ("symbol: %s", symbol); 
-        
-                price = strtok(NULL, ",");
-                price_val = strtod(price, NULL); 
+		tokens = g_strsplit (g_strchomp (line), ",", 0); 
 
-                change = strtok(NULL, ",");
-                /* file in DOS format: remove \r\n */
-                change[strlen(change) -1] = 0;
-                change[strlen(change) -1] = 0;
-                change_val = strtod(change, NULL); 
-               
-		/* GNOME Bug 143737 - prothonotar@tarnation.dyndns.org */ 
-                percent = (change_val/(price_val-change_val))*1E+02; 
+		if (g_strv_length (tokens) != 3)
+			goto out;
 
-                /* Restore numeric format for displaying */
-                setlocale(LC_NUMERIC, g_getenv ("LANG"));
-                
-                if (change_val == 0.0)
-                        sprintf(result,"%s:%1.2f:%1.2f:%1.2f%%",
-                                symbol,price_val,change_val,percent);
-                else
-                        sprintf(result,"%s:%1.2f:%1.2f:%+1.2f%%",
-                                symbol,price_val,change_val,percent);
-        
-                return result;
+		symbol = tokens[0];
+		price_val = g_ascii_strtod (tokens[1], NULL);
+		change_val = g_ascii_strtod (tokens[2], NULL);
 
+		if (symbol[0] == '"')
+			symbol++;
+		if (symbol[strlen(symbol) - 1] == '"')
+			symbol[strlen(symbol) - 1] = '\0';
+
+		percent = (100.0 * change_val) / (price_val - change_val);
+
+		if (change_val == 0.0)
+			result = g_strdup_printf ("%s:%1.3f:%1.3f:%1.2f%%",
+					symbol,price_val,change_val,percent);
+		else
+			result = g_strdup_printf ("%s:%1.3f:%1.3f:%+1.2f%%",
+					symbol,price_val,change_val,percent);
+
+	out:
+		g_strfreev (tokens);
+
+		return result;
 	}
 
 
 
 	/*-----------------------------------------------------------------*/
 	int configured(StockData *stockdata) {
-		int retVar;
-
+		int retVar = 0;
 		char  buffer[MAX_SYMBOL_LEN];
 		static FILE *CONFIG;
+		char *parsed;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
 
-		retVar = 0;
-
 		/* clear the output variable */
 		reSetOutputArray(stockdata);
 
@@ -488,20 +484,20 @@ static gint updateOutput(gpointer data)
 				fgets(buffer, sizeof(buffer)-1, CONFIG);
 
 				if (!feof(CONFIG)) {
+					parsed = parseQuote (buffer);
 
-				      setOutputArray(stockdata, parseQuote(buffer));
-				      retVar = 1;
-				}
-				else {
-				      retVar = (retVar > 0) ? retVar : 0;
+					if (parsed == NULL)
+						continue;
+
+				 	setOutputArray(stockdata, parsed);
+					g_free (parsed);
+
+					retVar = 1;
 				}
 			}
 			fclose(CONFIG);
 
 		}
-		else {
-			retVar = 0;
-		}
 
 		return retVar;
 	}
@@ -555,13 +551,10 @@ static gint updateOutput(gpointer data)
 		StockData *stockdata = data;
 		GtkWidget* drawing_area = stockdata->drawing_area;
 		GArray *quotes = stockdata->quotes;
-		PangoFontDescription *my_font = stockdata->my_font;
 		GdkGC *gc = stockdata->gc;
 		GdkRectangle update_rect;
 		PangoLayout *layout;
-		PangoRectangle logical_rect;
 		int	comp;
-		gint n = 0, totalLen2 = 0;
 		int start, end, width, max_height=0, y;
 
 		/* FOR COLOR */
@@ -756,7 +749,7 @@ static gint updateOutput(gpointer data)
 	static void zipLeft(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
 		gboolean current;
-		gint i, temp;
+		gint temp;
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = TRUE;
@@ -772,7 +765,7 @@ static gint updateOutput(gpointer data)
 	static void zipRight(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
 		gboolean current;
-		gint i, temp;
+		gint temp;
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = FALSE;
@@ -784,16 +777,6 @@ static gint updateOutput(gpointer data)
 		stockdata->props.scroll = current;
 	}
 
-	/*-----------------------------------------------------------------*/
-
-	static void selected_cb(GtkCList *clist,gint row, gint column, 
-				GdkEventButton *event, gpointer data) {
-		GtkWidget *button;
-
-		button = GTK_WIDGET(data);
-		soft_set_sensitive(button,TRUE);
-	}
-
 	/*-----------------------------------------------------------------*/
 	static gboolean timeout_cb(GtkWidget *spin, GdkEventFocus *event, gpointer data ) {
 		StockData *stockdata = data;
@@ -1127,47 +1110,30 @@ static gint updateOutput(gpointer data)
 
         static void populatelist(StockData *stockdata, GtkWidget *list) {
 	
-		gchar *symbol;
-		gchar *syms;
-		gchar *temp;
 		GtkTreeModel *model;
 		GtkTreeIter row;
+		char **syms;
+		int i;
 		
-		if (!stockdata->props.tik_syms)
+		if (stockdata->props.tik_syms == NULL)
 			return;
-			
-		syms = g_strdup(stockdata->props.tik_syms);
 
-		if ((temp=strtok(syms,"+")))
-			symbol = g_strdup(temp);
-		
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
-		while (symbol) {
+
+		syms = g_strsplit (stockdata->props.tik_syms, "+", 0);
+
+		for (i = 0; syms[i]; i++)
+		{
 			gtk_list_store_append (GTK_LIST_STORE (model), &row);
 			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
-					    0, symbol, -1);
-			g_free (symbol);
-			if ((temp=strtok(NULL,"+"))) 
-				symbol = g_strdup(temp);
-			else
-				symbol=NULL;
+					    0, syms[i], -1);
 		}
 		
-		if ((temp=strtok(NULL,""))) {
-			symbol = g_strdup(temp);
-			gtk_list_store_append (GTK_LIST_STORE (model), &row);
-			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
-					    0, symbol, -1);
-			g_free (symbol);
-		}
-		
-		g_free (syms);
-		
+		g_strfreev (syms);
 	}
 
 
 	static GtkWidget *symbolManager(StockData *stockdata) { 
-		GtkWidget *vbox;
 		GtkWidget *mainhbox;
 		GtkWidget *hbox;
 		GtkWidget *list;
@@ -1179,7 +1145,6 @@ static gint updateOutput(gpointer data)
 		GtkWidget *label;
 		GtkWidget *entry;
 		static GtkWidget *button;
-		GtkSizeGroup *size_group;
 
 		model = gtk_list_store_new (1, G_TYPE_STRING);
 		list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
@@ -1328,7 +1293,7 @@ static gint updateOutput(gpointer data)
 		StockData * stockdata = data;
 		GtkWidget * notebook;
 		GtkWidget * vbox, *behav_vbox, *appear_vbox;
-		GtkWidget * vbox2, *color_vbox;
+		GtkWidget *color_vbox;
 		GtkWidget *hbox, *hbox2, *hbox3, *font_hbox;
 		GtkWidget * label, *spin, *check;
 		GtkWidget *color;
@@ -1336,9 +1301,8 @@ static gint updateOutput(gpointer data)
 		GtkWidget *option, *menu, *menuitem;
 		GtkSizeGroup *size, *size2;
 		GdkColor gdkcolor;
+		int ur, ug, ub;
 
-		int ur,ug,ub, dr,dg,db; 
-				
 		if (stockdata->pb) {
 			gtk_window_set_screen (GTK_WINDOW (stockdata->pb),
 					       gtk_widget_get_screen (stockdata->applet));
@@ -2193,32 +2157,3 @@ static gint updateOutput(gpointer data)
 			return NULL;
 		
 	}
-
-	static gchar* gtik_get_text(void) {
-		GArray *quotes = access_stock->quotes;
-		gchar **strs = NULL;
-		gchar *buff;
-		gint i;
-
-		strs = g_new0 (gchar*, access_stock->setCounter + 1);
-		g_return_val_if_fail (strs != NULL, NULL);
-
-		for(i=0;i<access_stock->setCounter;i++) {
-			if (access_stock->props.output == FALSE) {
-				strs[i] = g_strdup_printf ("%s  %s",
-					STOCK_QUOTE (quotes->data)[i].price,
-					STOCK_QUOTE (quotes->data)[i].change);
-			}
-			else {
-				strs[i] = g_strdup_printf ("%s",
-					STOCK_QUOTE (quotes->data)[i].price);
-			}
-		}
-		buff = g_strjoinv ("  ", strs);
-
-		g_strfreev (strs);
-
-		return buff;
-	}
-
-
